@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 
 """
+boilerplate automation:
+
 filesystem template interpreter
 """
 
@@ -425,7 +427,7 @@ def main(args=sys.argv[1:]):
                           default=True, action='store_false',
                           help="don't read ~/.makeitso")
 
-    # TODO
+    # TODO:
 #     parser.add_option('-u', '--update', dest='update',
 #                       help="update the specified .ini file for variables read from this run")
 #     parser.add_option('-U', '--Update', dest='Update',
