@@ -20,6 +20,7 @@ Several components are included.
 
 import os
 import shutil
+import string
 import sys
 from cli import MakeItSoCLI
 from makeitso import ContentTemplate
@@ -27,6 +28,9 @@ from optparse import OptionParser
 from template import MakeItSoTemplate
 from template import Variable
 
+class SetupPy(MakeItSoTemplate):
+    """template for setup.py"""
+    templates = [('python_package', 'setup.py')]
 
 class PythonTemplate(MakeItSoTemplate):
   """abstract base class for python-type templates"""
@@ -97,8 +101,9 @@ class PythonPackageTemplate(PythonTemplate):
     variables['project'] = self.output2name(output)
 
     # get package name from project
-    # XXX could have looser restrictions with transforms
-    assert variables['project'].isalnum(), 'Project name must be just letters, you gave %s' % variables['project']
+    allowable = set(string.letters + string.digits + '_')
+    if not set(variables['project']).issubset(allowable):
+        raise AssertionError("Illegal fields in package name")
     variables['package'] = variables['project'].lower()
 
     # name of CLI main file
@@ -120,7 +125,9 @@ class PythonPackageTemplate(PythonTemplate):
       script_strings = ['[console_scripts]']
       for console_script in console_scripts:
         template = ContentTemplate(console_script)
-        output = template.substitute(project=variables['project'])
+        output = template.substitute(project=variables['project'],
+                                     package=variables['package'],
+                                     main=variables['main'])
         script_strings.append(output)
       variables['console_scripts'] = '\n'.join([' ' * len(s) + i
                                                 for i in script_strings])
